@@ -21,12 +21,13 @@
    along with libtunepimp; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-   $Id: c_wrapper.cpp,v 1.40 2004/03/05 20:27:59 robert Exp $
+   $Id: c_wrapper.cpp 8360 2006-08-07 21:05:12Z luks $
 
 ----------------------------------------------------------------------------*/
 #include "tunepimp.h"
 #include "mutex.h"
 #include "tp_c.h"
+#include "astrcmp.h"
 
 #define DB printf("%s:%d\n", __FILE__, __LINE__);
 
@@ -43,6 +44,27 @@
 
 #include <deque>
 
+class NotifyData
+{
+    public:
+
+        bool operator==(const NotifyData &other)
+        {
+            return status == other.status && type == other.type && fileId == other.fileId;
+        }
+        void operator=(const NotifyData &other)
+        {
+            status = other.status;
+            type = other.type;
+            fileId = other.fileId;
+        }
+
+        TPFileStatus   status;
+        TPCallbackEnum type;
+        int            fileId;
+
+};
+
 class Callback : public TPCallback
 {
     public:
@@ -55,27 +77,28 @@ class Callback : public TPCallback
         };
         virtual ~Callback(void) {};
 
-        void notify(TunePimp *pimp, TPCallbackEnum type, int fileId)
+        void notify(TunePimp *pimp, TPCallbackEnum type, int fileId, TPFileStatus status)
         {
             notifyMutex.acquire();
             if (notifyCallback)
-                (*notifyCallback)((tunepimp_t)pimp, notifyData, type, fileId);
+                (*notifyCallback)((tunepimp_t)pimp, notifyData, type, fileId, status);
             else
             {
-                pair<TPCallbackEnum, int> p, top;
-                bool                      add = true;
+                NotifyData   p, top;
+                bool         add = true;
 
                 if (notifyQueue.size() > 0)
                 {
                     top = notifyQueue.front();
-                    if (top.first == type && top.second == fileId)
+                    if (top.type == type && top.fileId == fileId && top.status == status)
                         add = false; 
                 }
 
                 if (add)
                 {
-                    p.first = type;
-                    p.second = fileId;
+                    p.type = type;
+                    p.fileId = fileId;
+                    p.status = status;
                     notifyQueue.push_back(p);
                 }
             }
@@ -90,20 +113,21 @@ class Callback : public TPCallback
                 statusQueue.push_back(status);
             statusMutex.release();
         };
-        bool getNotification(TPCallbackEnum &type, int &fileId)
+        bool getNotification(TPCallbackEnum &type, int &fileId, TPFileStatus &status)
         {
             bool ret = false;
 
             notifyMutex.acquire();
             if (notifyQueue.size() > 0)
             {
-                pair<TPCallbackEnum, int> p;
+                NotifyData p;
 
                 p = notifyQueue.front();
                 notifyQueue.pop_front();
 
-                type = p.first;
-                fileId = p.second;
+                type = p.type;
+                fileId = p.fileId;
+                status = p.status;
 
                 ret = true;
             }
@@ -132,10 +156,10 @@ class Callback : public TPCallback
 
     private:
 
-        TunePimp                          *tunePimp;
-        deque<pair<TPCallbackEnum, int> >  notifyQueue;
-        deque<string>                      statusQueue;
-        Mutex                              statusMutex, notifyMutex;
+        TunePimp          *tunePimp;
+        deque<NotifyData>  notifyQueue;
+        deque<string>      statusQueue;
+        Mutex              statusMutex, notifyMutex;
 };
 
 extern "C"
@@ -151,9 +175,10 @@ tunepimp_t tp_New(const char *appName, const char *appVersion)
     return (tunepimp_t)pimp;
 }
 
-tunepimp_t tp_NewWithArgs(const char *appName, const char *appVersion, int startThreads)
+tunepimp_t tp_NewWithArgs(const char *appName, const char *appVersion, 
+                          int startThreads, const char *pluginDir)
 {
-    TunePimp *pimp = new TunePimp(appName, appVersion, startThreads);
+    TunePimp *pimp = new TunePimp(appName, appVersion, startThreads, pluginDir);
     Callback *cb = new Callback();
 
     pimp->setCallback(cb);
@@ -214,14 +239,14 @@ tp_status_callback tp_GetStatusCallback(tunepimp_t o)
     return cb->statusCallback;
 }
 
-int tp_GetNotification(tunepimp_t o, TPCallbackEnum *type, int *fileId)
+int tp_GetNotification(tunepimp_t o, TPCallbackEnum *type, int *fileId, TPFileStatus *status)
 {
     Callback *cb;
 
     TP_OBJ_CHECK(o);
 
     cb = (Callback *)obj->getCallback();
-    return (int)cb->getNotification(*type, *fileId);
+    return (int)cb->getNotification(*type, *fileId, *status);
 }
 
 int tp_GetStatus(tunepimp_t o, char *status, int statusLen)
@@ -307,38 +332,36 @@ void tp_GetProxy(tunepimp_t o,
     proxyAddr[maxLen - 1] = 0;
 }
 
-void tp_SetUseUTF8(tunepimp_t o, int UTF8)
+void tp_SetFileNameEncoding(tunepimp_t o, const char *encoding)
 {
     TP_OBJ_CHECKV(o);
-    obj->setUseUTF8((bool)UTF8);
+    obj->setFileNameEncoding(string(encoding));
 }
 
-int tp_GetUseUTF8(tunepimp_t o)
+void tp_GetFileNameEncoding(tunepimp_t o, char *encoding, int maxEncodingLen)
 {
-    TP_OBJ_CHECK(o);
-    return obj->getUseUTF8();
+    string temp;
+    TP_OBJ_CHECKV(o);
+    temp = obj->getFileNameEncoding();
+    strncpy(encoding, temp.c_str(), maxEncodingLen - 1);
+    encoding[maxEncodingLen - 1] = 0;
 }
 
-void tp_SetUserInfo(tunepimp_t o, const char *userName, const char *password)
+void tp_SetMusicDNSClientId(tunepimp_t o, const char *clientId)
 {
     TP_OBJ_CHECKV(o);
-    obj->setUserInfo(userName, password);
+    obj->setMusicDNSClientId(clientId);
 }
 
-void tp_GetUserInfo(tunepimp_t o,
-                    char *userName, int maxUserNameLen,
-                    char *password, int maxPasswordLen)
+void tp_GetMusicDNSClientId(tunepimp_t o, char *clientId, int maxClientIdLen)
 {
-    string tmpUserName;
-    string tmpPassword;
+    string tmpClientId;
 
     TP_OBJ_CHECKV(o);
 
-    obj->getUserInfo(tmpUserName, tmpPassword);
-    strncpy(userName, tmpUserName.c_str(), maxUserNameLen - 1);
-    userName[maxUserNameLen - 1] = 0;
-    strncpy(password, tmpPassword.c_str(), maxPasswordLen - 1);
-    password[maxPasswordLen - 1] = 0;
+    tmpClientId = obj->getMusicDNSClientId();
+    strncpy(clientId, tmpClientId.c_str(), maxClientIdLen - 1);
+    clientId[maxClientIdLen - 1] = 0;
 }
 
 int tp_GetNumSupportedExtensions(tunepimp_t o)
@@ -381,18 +404,6 @@ TPThreadPriorityEnum tp_GetAnalyzerPriority(tunepimp_t o)
     return obj->getAnalyzerPriority();
 }
 
-void tp_SetAutoFileLookup(tunepimp_t o, int enable)
-{
-    TP_OBJ_CHECKV(o);
-    obj->setAutoFileLookup((bool)enable);
-}
-
-int tp_GetAutoFileLookup(tunepimp_t o)
-{
-    TP_OBJ_CHECK(o);
-    return obj->getAutoFileLookup();
-}
-
 void tp_GetError(tunepimp_t o, char *error, int maxLen)
 {
     string err;
@@ -404,10 +415,10 @@ void tp_GetError(tunepimp_t o, char *error, int maxLen)
     error[maxLen - 1] = 0;
 }
 
-int tp_AddFile(tunepimp_t o, const char *fileName)
+int tp_AddFile(tunepimp_t o, const char *fileName, int readMetadataNow)
 {
     TP_OBJ_CHECK(o);
-    return (int)obj->addFile(fileName);
+    return (int)obj->addFile(fileName, readMetadataNow);
 }
 
 int tp_AddDir(tunepimp_t o, const char *dirPath)
@@ -434,12 +445,6 @@ int tp_GetNumFiles(tunepimp_t o)
     return obj->getNumFiles();
 }
 
-int tp_GetNumUnsubmitted(tunepimp_t o)
-{
-    TP_OBJ_CHECK(o);
-    return obj->getNumUnsubmitted();
-}
-
 int tp_GetTrackCounts(tunepimp_t o, int *counts, int maxCounts)
 {
     map<TPFileStatus, int> countMap;
@@ -499,20 +504,6 @@ void tp_ReleaseTrack(tunepimp_t o, track_t track)
     obj->releaseTrack((Track *)track);
 }
 
-TPError tp_SelectResult(tunepimp_t o, track_t track, int resultIndex)
-{
-    TunePimp *obj = (TunePimp *)o;
-    if (o == NULL)
-        return tpInvalidObject;
-
-    if (track == NULL)
-        return tpInvalidObject;
-
-    obj->selectResult((Track *)track, resultIndex);
-
-    return tpOk;
-}
-
 void tp_Misidentified(tunepimp_t o, int fileId)
 {
     TP_OBJ_CHECKV(o);
@@ -572,21 +563,6 @@ int tp_WriteTags(tunepimp_t o, int *fileIds, int numFileIds)
     return obj->writeTags(&ids);
 }
 
-void tp_AddTRMSubmission(tunepimp_t o, const char *trackId, const char *trmId)
-{
-    TP_OBJ_CHECKV(o);
-    obj->addTRMSubmission(string(trackId), string(trmId));
-}
-
-TPError tp_SubmitTRMs(tunepimp_t o)
-{
-    TunePimp *obj = (TunePimp *)o;
-    if (o == NULL)
-        return tpInvalidObject;
-
-    return obj->submitTRMs();
-}
-
 void tp_SetRenameFiles(tunepimp_t o, int rename)
 {
     TP_OBJ_CHECKV(o);
@@ -623,6 +599,33 @@ int tp_GetWriteID3v1(tunepimp_t o)
     return obj->getWriteID3v1();
 }
 
+void tp_SetWriteID3v2_3(tunepimp_t o, int writeID3v2_3)
+{
+    TP_OBJ_CHECKV(o);
+    obj->setWriteID3v2_3(writeID3v2_3);
+}
+
+int tp_GetWriteID3v2_3(tunepimp_t o)
+{
+    TP_OBJ_CHECK(o);
+    return obj->getWriteID3v2_3();
+}
+
+void tp_SetID3Encoding(tunepimp_t o, TPID3Encoding encoding)
+{
+    TP_OBJ_CHECKV(o);
+    obj->setID3Encoding(encoding);
+}
+
+TPID3Encoding tp_GetID3Encoding(tunepimp_t o)
+{
+    TunePimp *obj = (TunePimp *)o;
+    if (obj == NULL) 
+        return eEncodingError;
+
+    return obj->getID3Encoding();
+}
+
 void tp_SetClearTags(tunepimp_t o, int clearTags)
 {
     TP_OBJ_CHECKV(o);
@@ -635,6 +638,18 @@ int tp_GetClearTags(tunepimp_t o)
     return obj->getClearTags();
 }
 
+void tp_SetWinSafeFileNames(tunepimp_t o, int winSafeFileNames)
+{
+    TP_OBJ_CHECKV(o);
+    obj->setWinSafeFileNames((bool)winSafeFileNames);
+}
+
+int tp_GetWinSafeFileNames(tunepimp_t o)
+{
+    TP_OBJ_CHECK(o);
+    return obj->getWinSafeFileNames();
+}
+
 void tp_SetFileMask(tunepimp_t o, const char *fileMask)
 {
     TP_OBJ_CHECKV(o);
@@ -669,6 +684,23 @@ void tp_GetVariousFileMask(tunepimp_t o, char *variousFileMask, int maxLen)
     variousFileMask[maxLen - 1] = 0;
 }
 
+void tp_SetNonAlbumFileMask(tunepimp_t o, const char *nonAlbumFileMask)
+{
+    TP_OBJ_CHECKV(o);
+    obj->setNonAlbumFileMask(nonAlbumFileMask);
+}
+
+void tp_GetNonAlbumFileMask(tunepimp_t o, char *nonAlbumFileMask, int maxLen)
+{
+    string tmpNonAlbumFileMask;
+
+    TP_OBJ_CHECKV(o);
+
+    tmpNonAlbumFileMask = obj->getNonAlbumFileMask();
+    strncpy(nonAlbumFileMask, tmpNonAlbumFileMask.c_str(), maxLen - 1);
+    nonAlbumFileMask[maxLen - 1] = 0;
+}
+
 void tp_SetAllowedFileCharacters(tunepimp_t o, const char *allowedCharacters)
 {
     TP_OBJ_CHECKV(o);
@@ -720,18 +752,6 @@ void tp_GetTopSrcDir(tunepimp_t o, char *topSrcDir, int maxLen)
     topSrcDir[maxLen - 1] = 0;
 }
 
-void tp_SetTRMCollisionThreshold(tunepimp_t o, int trmThreshold)
-{
-    TP_OBJ_CHECKV(o);
-    obj->setTRMCollisionThreshold(trmThreshold);
-}
-
-int tp_GetTRMCollisionThreshold(tunepimp_t o)
-{
-    TP_OBJ_CHECK(o);
-    return obj->getTRMCollisionThreshold();
-}
-
 void tp_SetAutoSaveThreshold(tunepimp_t o, int autoSaveThreshold)
 {
     TP_OBJ_CHECKV(o);
@@ -744,18 +764,6 @@ int tp_GetAutoSaveThreshold(tunepimp_t o)
     return obj->getAutoSaveThreshold();
 }
 
-void tp_SetMinTRMThreshold(tunepimp_t o, int minThreshold)
-{
-    TP_OBJ_CHECKV(o);
-    obj->setMinTRMThreshold(minThreshold);
-}
-
-int tp_GetMinTRMThreshold(tunepimp_t o)
-{
-    TP_OBJ_CHECK(o);
-    return obj->getMinTRMThreshold();
-}
-
 void tp_SetMaxFileNameLen(tunepimp_t o, int maxFileNameLen)
 {
     TP_OBJ_CHECKV(o);
@@ -818,15 +826,15 @@ void tr_GetFileName(track_t t, char *fileName, int maxLen)
     fileName[maxLen - 1] = 0;
 }
 
-void tr_GetTRM(track_t t, char *trmArg, int maxLen)
+void tr_GetPUID(track_t t, char *puidArg, int maxLen)
 {
-    string trm;
+    string puid;
 
     TR_OBJ_CHECKV(t);
 
-    obj->getTRM(trm);
-    strncpy(trmArg, trm.c_str(), maxLen - 1);
-    trmArg[maxLen - 1] = 0;
+    obj->getPUID(puid);
+    strncpy(puidArg, puid.c_str(), maxLen - 1);
+    puidArg[maxLen - 1] = 0;
 }
 
 void tr_GetLocalMetadata(track_t t, metadata_t *mdata)
@@ -836,28 +844,7 @@ void tr_GetLocalMetadata(track_t t, metadata_t *mdata)
     TR_OBJ_CHECKV(t);
 
     obj->getLocalMetadata(data);
-    md_Clear(mdata);
-
-    mdata->artist = strdup(data.artist.c_str());
-    mdata->sortName = strdup(data.sortName.c_str());
-    mdata->album = strdup(data.album.c_str());
-    mdata->track = strdup(data.track.c_str());
-    mdata->trackNum = data.trackNum;
-    mdata->variousArtist = (bool)data.variousArtist;
-    mdata->artistId = strdup(data.artistId.c_str());
-    mdata->albumId = strdup(data.albumId.c_str());
-    mdata->trackId = strdup(data.trackId.c_str());
-    mdata->fileTrm = strdup(data.fileTrm.c_str());
-    mdata->albumArtistId = strdup(data.albumArtistId.c_str());
-    mdata->duration = data.duration;
-    mdata->albumType = data.albumType;
-    mdata->albumStatus = data.albumStatus;
-    mdata->fileFormat = strdup(data.fileFormat.c_str());
-    mdata->numTRMIds = data.numTRMIds;
-    mdata->releaseYear = data.releaseYear;
-    mdata->releaseMonth = data.releaseMonth;
-    mdata->releaseDay = data.releaseDay;
-    strcpy(mdata->releaseCountry, data.releaseCountry.c_str());
+    data.writeToC(mdata);
 }
 
 void tr_SetLocalMetadata(track_t t, const metadata_t *mdata)
@@ -866,26 +853,7 @@ void tr_SetLocalMetadata(track_t t, const metadata_t *mdata)
 
     TR_OBJ_CHECKV(t);
 
-    data.artist = mdata->artist ? mdata->artist : ""; 
-    data.sortName = mdata->sortName ? mdata->sortName : "";
-    data.album = mdata->album ? mdata->album : "";
-    data.track = mdata->track ? mdata->track : "";
-    data.trackNum = mdata->trackNum;
-    data.variousArtist = (bool)mdata->variousArtist;
-    data.artistId = mdata->artistId ? mdata->artistId : "";
-    data.albumId = mdata->albumId ? mdata->albumId : "";
-    data.trackId = mdata->trackId ? mdata->trackId : "";
-    data.fileTrm = mdata->fileTrm ? mdata->fileTrm : "";
-    data.albumArtistId = mdata->albumArtistId ? mdata->albumArtistId : "";
-    data.duration = mdata->duration;
-    data.albumType = mdata->albumType;
-    data.albumStatus = mdata->albumStatus;
-    data.numTRMIds = mdata->numTRMIds;
-    data.releaseYear = mdata->releaseYear;
-    data.releaseMonth = mdata->releaseMonth;
-    data.releaseDay = mdata->releaseDay;
-    data.releaseCountry = mdata->releaseCountry ? mdata->releaseCountry : "";
-
+    data.readFromC(mdata);
     obj->setLocalMetadata(data);
 }
 
@@ -896,27 +864,7 @@ void tr_GetServerMetadata(track_t t, metadata_t *mdata)
     TR_OBJ_CHECKV(t);
 
     obj->getServerMetadata(data);
-    md_Clear(mdata);
-
-    mdata->artist = strdup(data.artist.c_str());
-    mdata->sortName = strdup(data.sortName.c_str());
-    mdata->album = strdup(data.album.c_str());
-    mdata->track = strdup(data.track.c_str());
-    mdata->trackNum = data.trackNum;
-    mdata->variousArtist = (bool)data.variousArtist;
-    mdata->artistId = strdup(data.artistId.c_str());
-    mdata->albumId = strdup(data.albumId.c_str());
-    mdata->trackId = strdup(data.trackId.c_str());
-    mdata->fileTrm = strdup(data.fileTrm.c_str());
-    mdata->albumArtistId = strdup(data.albumArtistId.c_str());
-    mdata->duration = data.duration;
-    mdata->albumType = data.albumType;
-    mdata->albumStatus = data.albumStatus;
-    mdata->numTRMIds = data.numTRMIds;
-    mdata->releaseYear = data.releaseYear;
-    mdata->releaseMonth = data.releaseMonth;
-    mdata->releaseDay = data.releaseDay;
-    strcpy(mdata->releaseCountry, data.releaseCountry.c_str());
+    data.writeToC(mdata);
 }
 
 void tr_SetServerMetadata(track_t t, const metadata_t *mdata)
@@ -925,26 +873,7 @@ void tr_SetServerMetadata(track_t t, const metadata_t *mdata)
 
     TR_OBJ_CHECKV(t);
 
-    data.artist = mdata->artist ? mdata->artist : ""; 
-    data.sortName = mdata->sortName ? mdata->sortName : "";
-    data.album = mdata->album ? mdata->album : "";
-    data.track = mdata->track ? mdata->track : "";
-    data.trackNum = mdata->trackNum;
-    data.variousArtist = (bool)mdata->variousArtist;
-    data.artistId = mdata->artistId ? mdata->artistId : "";
-    data.albumId = mdata->albumId ? mdata->albumId : "";
-    data.trackId = mdata->trackId ? mdata->trackId : "";
-    data.fileTrm = mdata->fileTrm ? mdata->fileTrm : "";
-    data.albumArtistId = mdata->albumArtistId ? mdata->albumArtistId : "";
-    data.duration = mdata->duration;
-    data.albumType = mdata->albumType;
-    data.albumStatus = mdata->albumStatus;
-    data.numTRMIds = mdata->numTRMIds;
-    data.releaseYear = mdata->releaseYear;
-    data.releaseMonth = mdata->releaseMonth;
-    data.releaseDay = mdata->releaseDay;
-    data.releaseCountry = mdata->releaseCountry ? mdata->releaseCountry : "";
-
+    data.readFromC(mdata);
     obj->setServerMetadata(data);
 }
 
@@ -971,158 +900,18 @@ int tr_HasChanged(track_t t)
     return (int)obj->hasChanged();
 }
 
+void tr_SetChanged(track_t t)
+{
+    TR_OBJ_CHECKV(t);
+    obj->setChanged();
+}
+
 void tr_SetStatus(track_t t, const TPFileStatus status)
 {
     TR_OBJ_CHECKV(t);
     obj->setStatus(status);
 }
 
-int tr_GetNumResults(track_t t)
-{
-    vector<TPResult *> res;
-    TPResultType       type;
-
-    TR_OBJ_CHECK(t);
-
-    obj->getResults(type, res);
-    return res.size();
-}
-
-static artistresult_t *convertArtistResult(TPArtistResult *res)
-{
-    artistresult_t *ar;
-
-    ar = (artistresult_t *)calloc(sizeof(artistresult_t), 1);
-    ar->relevance = res->getRelevance();
-    ar->name = strdup(res->getName().c_str());
-    ar->sortName = strdup(res->getSortName().c_str());
-    ar->id = strdup(res->getId().c_str());
-
-    //printf("Artist res: %d %s %s %s\n", ar->relevance, ar->name, ar->sortName, ar->id);
-
-    return ar;
-}
-
-static void deleteArtistResult(artistresult_t *res)
-{
-    if (!res)
-        return;
-
-    if (res->name)
-        free(res->name);
-
-    if (res->sortName)
-        free(res->sortName);
-
-    if (res->id)
-        free(res->id);
-
-    free(res);
-}
-
-static albumresult_t *convertAlbumResult(TPAlbumResult *res)
-{
-    albumresult_t *al;
-    TPArtistResult artist;
-
-    al = (albumresult_t *)calloc(sizeof(albumresult_t), 1);
-    al->relevance = res->getRelevance();
-    al->name = strdup(res->getName().c_str());
-    al->id = strdup(res->getId().c_str());
-    al->numTracks = res->getNumTracks();
-    al->numCDIndexIds = res->getNumCDIndexIds();
-    al->isVA = (int)res->getVariousArtists();
-    al->status = res->getStatus();
-    al->type = res->getType();
-
-    artist = res->getArtist();
-    al->artist = convertArtistResult(&artist);
-
-    return al;
-}
-
-static void deleteAlbumResult(albumresult_t *res)
-{
-    if (!res)
-        return;
-
-    if (res->name)
-        free(res->name);
-
-    if (res->id)
-        free(res->id);
-
-    free(res);
-}
-
-static albumtrackresult_t *convertAlbumTrackResult(TPAlbumTrackResult *res)
-{
-    albumtrackresult_t *tr;
-    TPArtistResult     artist;
-    TPAlbumResult      album;
-
-    tr = (albumtrackresult_t *)calloc(sizeof(albumtrackresult_t), 1);
-    tr->relevance = res->getRelevance();
-    tr->name = strdup(res->getName().c_str());
-    tr->id = strdup(res->getId().c_str());
-    tr->numTRMIds = res->getNumTRMIds();
-    tr->trackNum = res->getTrackNum();
-    tr->duration = res->getDuration();
-
-    artist = res->getArtist();
-    tr->artist = convertArtistResult(&artist);
-
-    album = res->getAlbum();
-    tr->album = convertAlbumResult(&album);
-
-    return tr;
-}
-
-static void deleteAlbumTrackResult(albumtrackresult_t *res)
-{
-    if (!res)
-        return;
-
-    if (res->name)
-        free(res->name);
-
-    if (res->id)
-        free(res->id);
-
-    free(res);
-}
-
-void tr_GetResults(track_t t, TPResultType *type, result_t *results, int *numResults)
-{
-    vector<TPResult *> res;
-    vector<TPResult *>::iterator i;
-    int                          count;
-
-    TR_OBJ_CHECKV(t);
-
-    obj->getResults(*type, res);
-    for(i = res.begin(), count = 0; i != res.end() && *numResults >= 0;
-        i++, (*numResults)--, results++, count++)
-    {
-        switch(*type)
-        {
-            case eArtistList:
-                *results = convertArtistResult((TPArtistResult *)(*i));
-                break;
-            case eAlbumList:
-                *results = convertAlbumResult((TPAlbumResult *)(*i));
-                break;
-            case eTrackList:
-                *results = convertAlbumTrackResult((TPAlbumTrackResult *)(*i));
-                break;
-            default:
-                *results = NULL;
-                break;
-        }
-    }
-    *numResults = count;
-}
-
 void tr_Lock(track_t t)
 {
     TR_OBJ_CHECKV(t);
@@ -1135,33 +924,9 @@ void tr_Unlock(track_t t)
     obj->unlock();
 }
 
-/* --------------------------------------------------------------------------
- * Result Interface
- * --------------------------------------------------------------------------*/
-
-void rs_Delete(TPResultType type, result_t *result, int numResults)
-{
-    for(; numResults > 0; numResults--, result++)
-        switch(type)
-        {
-            case eArtistList:
-                deleteArtistResult((artistresult_t *)*result);
-                break;
-            case eAlbumList:
-                deleteAlbumResult((albumresult_t *)*result);
-                break;
-            case eTrackList:
-                deleteAlbumTrackResult((albumtrackresult_t *)*result);
-                break;
-            default:
-                break;
-        }
-}
-
 /* --------------------------------------------------------------------------
  * Metadata Interface
  * --------------------------------------------------------------------------*/
-
 metadata_t *md_New(void)
 {
     return (metadata_t *)calloc(sizeof(metadata_t), 1);
@@ -1172,8 +937,6 @@ void md_Delete(metadata_t *data)
     if (!data)
         return;
 
-    md_Clear(data);
-
     free(data);
 }
 
@@ -1182,30 +945,23 @@ void md_Clear(metadata_t *data)
     if (!data)
         return;
 
-    if (data->artist)
-        free(data->artist);
-    if (data->sortName)
-        free(data->sortName);
-    if (data->album)
-        free(data->album);
-    if (data->track)
-        free(data->track);
-    if (data->artistId)
-        free(data->artistId);
-    if (data->albumId)
-        free(data->albumId);
-    if (data->trackId)
-        free(data->trackId);
-    if (data->fileTrm)
-        free(data->fileTrm);
-    if (data->albumArtistId)
-        free(data->albumArtistId);
-    if (data->fileFormat)
-    free(data->fileFormat);
-
     memset(data, 0, sizeof(metadata_t));
 }
 
+int md_Compare(const metadata_t *A, const metadata_t *B)
+{
+    MetadataCompare comp;
+    Metadata mdataA, mdataB;
+
+    if (!A || !B)
+        return 0;
+
+    mdataA.readFromC(A);
+    mdataB.readFromC(B);
+
+    return comp.compare(mdataA, mdataB);
+}
+
 TPAlbumStatus md_ConvertToAlbumStatus(const char *albumStatus)
 {
     return convertToAlbumStatus(albumStatus);
@@ -1234,4 +990,8 @@ void md_ConvertFromAlbumType(TPAlbumType type, char *albumType, int maxLen)
     albumType[maxLen - 1] = 0;
 }
 
+float md_Similarity(const char *a, const char *b)
+{
+    return astrcmp(a, b);
+}
 }
