@@ -21,7 +21,7 @@
    along with libtunepimp; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-   $Id: dirsearch.cpp,v 1.10 2006/01/07 19:19:37 luks Exp $
+   $Id: dirsearch.cpp 1461 2006-01-16 15:08:55Z luks $
 
 ----------------------------------------------------------------------------*/
 #include <stdio.h>
@@ -99,7 +99,7 @@ int DirSearch::recurseDir(const char *path)
    int                count = 0, j;
    char               newPath[MAX_PATH], savedPath[MAX_PATH];
    FileType           type;
-   static bool        wide = 0;//GetVersion() < 0x80000000;
+   static bool        wide = GetVersion() < 0x80000000;
    
    pimp->setStatus(string("Searching ") + string(path));
 
