@@ -6,8 +6,8 @@ use strict;
 use MusicBrainz::Tunepimp::tunepimp;
 
 use constant VARTIST_MBID   => "89ad4ac3-39f7-470e-963a-56509c546377";
-use constant CVS_ID			=> '$Id: tp_tagger.pl,v 1.4 2004/03/25 10:23:02 robert Exp $';
-use constant CVS_REVISION	=> '$Revision: 1.4 $';
+use constant CVS_ID			=> '$Id: tp_tagger.pl 1367 2005-02-21 01:10:28Z robert $';
+use constant CVS_REVISION	=> '$Revision: 1367 $';
 
 use MusicBrainz::Tunepimp::tunepimp qw(
 	:TPError
@@ -161,7 +161,8 @@ sub printTrack
     printf(" ArtistId: %s\n", $data->getArtistId);
     printf("  AlbumId: %s\n", $data->getAlbumId);
     printf("  TrackId: %s\n", $data->getTrackId);
-    printf("       VA: %d\n\n", $data->getVariousArtist);
+    printf("       VA: %d\n", $data->getVariousArtist);
+    printf("       NA: %d\n\n", $data->getNonAlbum);
 
 	$data = $track->getServerMetadata;
     printf("Server metadata:\n");
@@ -174,7 +175,14 @@ sub printTrack
     printf(" ArtistId: %s\n", $data->getArtistId);
     printf("  AlbumId: %s\n", $data->getAlbumId);
     printf("  TrackId: %s\n", $data->getTrackId);
-    printf("       VA: %d\n\n", $data->getVariousArtist);
+    printf("       VA: %d\n", $data->getVariousArtist);
+    printf("       NA: %d\n", $data->getNonAlbum);
+	printf("  Release: %04d-%02d-%02d %s\n",
+		$data->getReleaseYear,
+		$data->getReleaseMonth,
+		$data->getReleaseDay,
+		$data->getReleaseCountry || "",
+	) if $data->getReleaseYear;
     if ($data->getAlbumType != eAlbumType_Error)
     {
 		my $type = $data->getAlbumTypeNameFromNumber;
@@ -394,7 +402,7 @@ my $last_notify;
 
 sub notify
 {
-	my ($pimp, $data, $type, $id) = @_;
+	my ($pimp, $data, $type, $id, $status) = @_;
 	my $fileName;
 
     my $track = $pimp->getTrack($id);
@@ -419,7 +427,7 @@ sub notify
 	} elsif ($type == tpFileChanged) {
             if ($track)
 			{
-                $msg = sprintf("%s: %s\n", $fileStatusText{$track->getStatus}, $fileName);
+                $msg = sprintf("%s: %s\n", $fileStatusText{$status}, $fileName);
 			}
 	} elsif ($type == tpWriteTagsComplete) {
             $msg = sprintf("Writing tags complete!\n");
@@ -451,6 +459,7 @@ TRMCollisionThreshold
 topSrcDir
 useUTF8
 variousFileMask
+nonAlbumFileMask
 writeID3v1
 proxy
 server
@@ -558,6 +567,13 @@ $verb_handlers{"save-config"} = sub {
 	save_config($_[0], $_[2]);
 };
 
+$verb_handlers{"shell"} = $verb_handlers{"sh"} = sub {
+	my ($pimp, $context, @params) = check_args(\@_, 0, INFINITE, "[COMMAND]")
+		or return;
+	my $command = $context->{'last_params'} || $ENV{SHELL} || "/bin/sh";
+	system $command;
+};
+
 # the tagging process
 
 $verb_handlers{"list"} = $verb_handlers{"l"} = sub {
@@ -569,7 +585,13 @@ $verb_handlers{"list"} = $verb_handlers{"l"} = sub {
 $verb_handlers{"add-file"} = $verb_handlers{"a"} = sub {
 	my ($pimp, $context, @params) = check_args(\@_, 1, INFINITE, "FILE")
 		or return;
-	$pimp->addFile($context->{'last_params'});
+	$pimp->addFile($context->{'last_params'}, 0);
+};
+
+$verb_handlers{"glob"} = sub {
+	my ($pimp, $context, @params) = check_args(\@_, 1, INFINITE, "FILE")
+		or return;
+	$pimp->addFiles( glob($context->{'last_params'}) );
 };
 
 $verb_handlers{"add-directory"} = $verb_handlers{"d"} = sub {
@@ -623,6 +645,18 @@ $verb_handlers{"write-tags"} = $verb_handlers{"w"} = sub {
 	$pimp->writeTags($pimp->getFileIds) if not defined $params[0];
 };
 
+$verb_handlers{"remove"} = sub {
+	my ($pimp, $context, @params) = check_args(\@_, 1, INFINITE, "[FILE# ...]")
+		or return;
+	$pimp->remove($_) for @params;
+};
+
+$verb_handlers{"remove-all"} = sub {
+	my ($pimp, $context, @params) = check_args(\@_, 0, 0)
+		or return;
+	$pimp->remove($_) for $pimp->getFileIds;
+};
+
 $verb_handlers{"choose-result"} = $verb_handlers{"c"} = sub {
 	my ($pimp, $context, @params) = check_args(\@_, 2, 2, "FILE# CHOICE")
 		or return;
@@ -689,6 +723,15 @@ $verb_handlers{"set-va-filemask"} = $verb_handlers{"fv"} = sub {
 	printf("VariousFileMask is now %s\n", $pimp->getVariousFileMask);
 };
 
+$verb_handlers{"set-na-filemask"} = $verb_handlers{"fn"} = sub {
+	my ($pimp, $context, @params) = check_args(\@_, 1, INFINITE, "FILEMASK")
+		or return;
+	my $mask = $context->{'last_params'};
+	validate_file_mask($mask);
+	$pimp->setNonAlbumFileMask($mask);
+	printf("NonAlbumFileMask is now %s\n", $pimp->getNonAlbumFileMask);
+};
+
 # numberic options
 
 $verb_handlers{"set-trm-collision-threshold"} = $verb_handlers{"tc"} = sub {
@@ -758,12 +801,15 @@ Help:
 Command:  Arguments:        Function:
 ---------------------------------------------------------
    a      <filename>        Add file
+   glob   <mask>            Add files (wildcard)
    d      <dir>             Add files in dir
    l                        List files in tagger
    p      <file #>          Print details of file
    r      <file #>          Show the matches for a file lookup
    q                        Quit
    w      [file #s]         Write tags & rename files
+   remove <file #s>         Remove files from list
+   remove-all               Remove all files from list
    c      <file #> <choice> Choose a search result
    s                        Submit TRMs to server
    i      <file #>          Identify file again
@@ -784,9 +830,11 @@ Options:
    x                        Clear tags before writing new ones (%s)
    f      <mask>            Set the filemask (%s)
    fv     <va mask>         Set the various artist filemask (%s)
+   fn     <na mask>         Set the non-album filemask (%s)
    hv                       Show valid substitutions for use in filemasks
    save-config [FILE]       Save current configuration to FILE (default ~/.tunepimprc)
    load-config [FILE]       Load configuration from FILE (default ~/.tunepimprc)
+   shell  [command]         Spawn a shell or run a command
 
 EOF
 		$pimp->renameFiles ? "on" : "off",
@@ -800,6 +848,7 @@ EOF
 		$pimp->clearTags ? "on" : "off",
 		$pimp->fileMask,
 		$pimp->variousFileMask,
+		$pimp->nonAlbumFileMask,
 		;
 		
 	print "The complete set of commands I understand is: ";
@@ -832,6 +881,7 @@ sub main
     $pimp->setClearTags(0);
     $pimp->setFileMask("%sortname/%album/%sortname-%album-%0num-%track");
     $pimp->setVariousFileMask("Various Artists/%album/%album-%0num-%sortname-%track");
+    $pimp->setNonAlbumFileMask("%sortname/%album/%sortname--%track");
     $pimp->setAutoSaveThreshold(-1);
     $pimp->setTRMCollisionThreshold(80);
 	$pimp->setUserInfo("", "");
@@ -860,9 +910,9 @@ sub main
     while (not $context{quit})
     {
 		$last_notify = "";
-		while (my ($type, $fileId) = $pimp->getNotification)
+		while (my ($type, $fileId, $status) = $pimp->getNotification)
 		{
-            notify($pimp, undef, $type, $fileId);
+            notify($pimp, undef, $type, $fileId, $status);
 		}
 
         my $cmd = getCommand();
