@@ -23,7 +23,7 @@
 #   along with libtunepimp; if not, write to the Free Software
 #   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#   $Id: tunepimp.pm,v 1.10 2004/03/05 18:44:26 dave Exp $
+#   $Id: tunepimp.pm 1367 2005-02-21 01:10:28Z robert $
 #
 ##############################################################################
 
@@ -113,6 +113,7 @@ BEGIN
 			tpSubmitError		=> 4,
 			tpInvalidIndex		=> 5,
 			tpInvalidObject		=> 6,
+			tpErrorLast			=> 7,
 		},
 		TPCallbackEnum => {
 			tpFileAdded			=> 0,
@@ -122,17 +123,19 @@ BEGIN
 			tpCallbackLast		=> 4,
 		},
 		TPFileStatus => {
-			eUnrecognized => 0,		# unrecognized
-			eRecognized => 1,		# Recognized and previously saved
-			ePending => 2,			# pending trm calculation
-			eTRMLookup => 3,		# trm done, pending trm lookup
-			eTRMCollision => 4,		   # trm done, pending trm lookup
-			eFileLookup => 5,		# trm done, no matches, pending file lookup
-			eUserSelection => 6,	# file lookup done, needs user selection
-			eVerified => 7,			# User verified, about to write changes to disk 
-			eSaved => 8,			# Saved (renamed, taggs written)
-			eDeleted => 9,			# to be deleted, waiting for refcount == 0
-			eError => 10,			# Error
+			eMetadataRead => 0,
+			eUnrecognized => 1,		# unrecognized
+			eRecognized => 2,		# Recognized and previously saved
+			ePending => 3,			# pending trm calculation
+			eTRMLookup => 4,		# trm done, pending trm lookup
+			eTRMCollision => 5,		   # trm done, pending trm lookup
+			eFileLookup => 6,		# trm done, no matches, pending file lookup
+			eUserSelection => 7,	# file lookup done, needs user selection
+			eVerified => 8,			# User verified, about to write changes to disk 
+			eSaved => 9,			# Saved (renamed, taggs written)
+			eDeleted => 10,			# to be deleted, waiting for refcount == 0
+			eError => 11,			# Error
+			eLastStatus => 12,
 		},
 		TPResultType => {
 			eNone				=> 0,
@@ -175,7 +178,7 @@ BEGIN
 	use vars qw( @ISA $VERSION %EXPORT_TAGS @EXPORT_OK );
 
 	@ISA = qw( Exporter );
-	$VERSION = '0.02';
+	$VERSION = '0.03';
 
 	require XSLoader;
 	XSLoader::load('MusicBrainz::Tunepimp::tunepimp', $VERSION);
@@ -287,6 +290,7 @@ NO_getTracks
 getUseUTF8
 LIST_getUserInfo
 getVariousFileMask
+getNonAlbumFileMask
 getVersion
 getWriteID3v1
 		)
@@ -375,7 +379,7 @@ e.g. C<$tp-E<gt>addFiles(glob("*.mp3"))>
 sub addFiles
 {
 	my $self = shift;
-	map { $self->addFile($_) } @_;
+	map { $self->addFile($_, 0) } @_;
 }
 
 =item getRecognizedFileList
@@ -478,6 +482,7 @@ setTRMCollisionThreshold
 setTopSrcDir
 setUseUTF8
 setVariousFileMask
+setNonAlbumFileMask
 setWriteID3v1
 )) {
 	(my $get = $set) =~ s/^set/get/;
@@ -675,6 +680,7 @@ setAlbum
 setTrack
 setTrackNum
 setVariousArtist
+setNonAlbum
 setArtistId
 setAlbumId
 setTrackId
@@ -717,6 +723,7 @@ sub as_hashref
 		track			=> $self->getTrack,
 		tracknum		=> $self->getTrackNum,
 		variousartist	=> $self->getVariousArtist,
+		nonalbum	=> $self->getNonAlbum,
 		artistid		=> $self->getArtistId,
 		albumid			=> $self->getAlbumId,
 		trackid			=> $self->getTrackId,
@@ -725,6 +732,8 @@ sub as_hashref
 		duration		=> $self->getDuration,
 		albumtype		=> $self->getAlbumType,
 		fileFormat		=> $self->getFileFormat,
+		releaseDate		=> [ $self->getReleaseYear, $self->getReleaseMonth, $self->getReleaseDay ],
+		releaseCountry	=> $self->getReleaseCountry,
 		numtrmids		=> $self->getNumTrmIds,
 	};
 }
@@ -878,7 +887,7 @@ callback information, like so:
 
 =head1 AUTHOR
 
-Dave Evans, E<lt>djce@musicbrainz.orgE<gt>
+Dave Evans, L<http://djce.org.uk/>
 
 =head1 COPYRIGHT AND LICENSE
 
