@@ -21,13 +21,21 @@
    along with libtunepimp; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-   $Id: flacdecode.cpp 7230 2006-04-16 11:25:38Z luks $
+   $Id: flacdecode.cpp 8625 2006-11-05 22:13:17Z luks $
 
 ----------------------------------------------------------------------------*/
 #include <stdlib.h>
 #include <string.h>
 #include "flacdecode.h"
 
+#include <FLAC/export.h>
+/* FLAC 1.1.3 has FLAC_API_VERSION_CURRENT == 8 */
+#if !defined(FLAC_API_VERSION_CURRENT) || FLAC_API_VERSION_CURRENT < 8
+#define LEGACY_FLAC
+#else
+#undef LEGACY_FLAC
+#endif
+
 void FLAC_errorcb(const FLAC__StreamDecoder * decoder,
                   FLAC__StreamDecoderErrorStatus status, void *client_data)
 {
@@ -99,7 +107,11 @@ FLAC__StreamDecoderWriteStatus FLAC_writecb(const FLAC__StreamDecoder * decoder,
 
 FLAC__StreamDecoderReadStatus FLAC_readcb(const FLAC__StreamDecoder *decoder, 
                                           FLAC__byte buffer[], 
+#ifdef LEGACY_FLAC
                                           unsigned *bytes, 
+#else
+                                          size_t *bytes, 
+#endif
                                           void *client_data)
 {
    clientdata_t *cd = reinterpret_cast < clientdata_t * >(client_data);
@@ -131,6 +143,7 @@ FlacDecode::FlacDecode(const string & fileName, const string &encoding) : Decode
    if (!cd.in)
       return;
 
+#ifdef LEGACY_FLAC
    if (!FLAC__stream_decoder_set_read_callback(decoder, &FLAC_readcb))
       return;
 
@@ -149,6 +162,10 @@ FlacDecode::FlacDecode(const string & fileName, const string &encoding) : Decode
    state = FLAC__stream_decoder_init(decoder);
    if (state != FLAC__STREAM_DECODER_SEARCH_FOR_METADATA)
       return;
+#else
+   if (FLAC__stream_decoder_init_stream(decoder, &FLAC_readcb, NULL, NULL, NULL, NULL, &FLAC_writecb, &FLAC_metadatacb, &FLAC_errorcb, &cd) != FLAC__STREAM_DECODER_INIT_STATUS_OK)
+      return;
+#endif
 
    FLAC__stream_decoder_process_until_end_of_metadata(decoder);
    state = FLAC__stream_decoder_get_state(decoder);
