@@ -21,7 +21,7 @@
    along with libtunepimp; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-   $Id: id3_2_3_meta.cpp,v 1.14 2006/01/22 12:13:15 luks Exp $
+   $Id: id3_2_3_meta.cpp 7216 2006-04-14 23:10:49Z robert $
 
 ----------------------------------------------------------------------------*/
 
@@ -402,7 +402,7 @@ bool ID3_2_3::read(const string &fileName, Metadata &data)
     if (data.sortName.empty())
        data.sortName = getUserText(tag, "MusicBrainz Artist Sortname");
 
-    data.fileTrm = getUserText(tag, "MusicBrainz TRM Id");
+    data.filePUID = getUserText(tag, "MusicIP PUID");
     data.artistId = getUserText(tag, "MusicBrainz Artist Id");
     data.albumId = getUserText(tag, "MusicBrainz Album Id");
     data.albumArtistId = getUserText(tag, "MusicBrainz Album Artist Id");
@@ -497,7 +497,7 @@ bool ID3_2_3::write(const string  &fileName,
     else    
         setText(tag, "TCMP", "0");
         
-    setUserText(tag, "MusicBrainz TRM Id", data.fileTrm);
+    setUserText(tag, "MusicIP PUID", data.filePUID);
     setUserText(tag, "MusicBrainz Artist Id", data.artistId);
     setUserText(tag, "MusicBrainz Album Id", data.albumId);
     if (data.albumType != eAlbumType_Error)
