@@ -21,7 +21,7 @@
    along with libtunepimp; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-   $Id: id3_meta.cpp,v 1.22 2006/01/22 12:13:15 luks Exp $
+   $Id: id3_meta.cpp 8498 2006-09-29 21:31:25Z luks $
 
 ----------------------------------------------------------------------------*/
 
@@ -406,7 +406,7 @@ bool ID3::read(const string &fileName, Metadata &data)
     if (data.sortName.empty())
        data.sortName = getUserText(tag, "MusicBrainz Artist Sortname");
 
-    data.fileTrm = getUserText(tag, "MusicBrainz TRM Id");
+    data.filePUID = getUserText(tag, "MusicIP PUID");
     data.artistId = getUserText(tag, "MusicBrainz Artist Id");
     data.albumId = getUserText(tag, "MusicBrainz Album Id");
     data.albumArtistId = getUserText(tag, "MusicBrainz Album Artist Id");
@@ -432,13 +432,13 @@ bool ID3::read(const string &fileName, Metadata &data)
         data.releaseYear = atoi(temp.c_str());
 
     temp = getText(tag, "TDRL");
+    if (temp.empty())
+        temp = getText(tag, "TDRC");
     if (temp.empty())
         temp = getText(tag, "TDOR");
     if (temp.empty())
-    {
         temp = getText(tag, "XDOR");
-    }
-    if (temp.length())
+    if (!temp.empty())
     {
         int year, month, day;
 
@@ -508,7 +508,7 @@ bool ID3::write(const string  &fileName,
     else    
         setText(tag, "TCMP", "0");
         
-    setUserText(tag, "MusicBrainz TRM Id", data.fileTrm);
+    setUserText(tag, "MusicIP PUID", data.filePUID);
     setUserText(tag, "MusicBrainz Artist Id", data.artistId);
     setUserText(tag, "MusicBrainz Album Id", data.albumId);
 
