@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: tag.c,v 1.2 2005/05/24 05:29:15 robert Exp $
+ * $Id: tag.c 8460 2006-09-03 18:37:43Z luks $
  */
 
 # ifdef HAVE_CONFIG_H
@@ -610,6 +610,9 @@ struct id3_tag *v2_parse(id3_byte_t const *ptr)
       if (*ptr == 0)
 	break;  /* padding */
 
+      if (memcmp(ptr, "MP3ext", end - ptr < 6 ? end - ptr : 6) == 0) 
+	break;  /* non-standard 'MP3ext' padding */
+
       frame = id3_frame_parse(&ptr, end - ptr, tag->version);
       if (frame == 0 || id3_tag_attachframe(tag, frame) == -1)
 	goto fail;
