@@ -21,7 +21,7 @@
 #   along with libtunepimp; if not, write to the Free Software
 #   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#   $Id: track.py,v 1.13 2005/06/28 03:23:37 robert Exp $
+#   $Id: track.py 7869 2006-06-17 15:30:06Z luks $
 #
 #---------------------------------------------------------------------------
 
@@ -82,7 +82,7 @@ class albumtrackresult(Structure):
                 ("relevance", c_int),
                 ("name", trackNameType),
                 ("id", idType),
-                ("numTRMIds", c_int),
+                ("numPUIDs", c_int),
                 ("trackNum", c_int),
                 ("duration", c_ulong),
                 ("artist", artistresult),
@@ -97,15 +97,13 @@ class track(object):
     def __init__(self, tunePimp, tr):
         self.tunePimp = tunePimp
         self.tplib = tunePimp.tplib
-        self.tr = tr
-        self.tplib.tr_GetStatus.argtypes = [ c_int ]
-        self.tplib.tr_SetStatus.argtypes = [ c_int, c_int ]
-        self.tplib.tr_GetSimilarity.argtypes = [ c_int ]
-        self.tplib.tr_HasChanged.argtypes = [ c_int ]
-        self.tplib.tr_GetResults.argtypes = [ c_int ]
-        self.tplib.tr_Lock.argtypes = [ c_int ]
-        self.tplib.tr_Unlock.argtypes = [ c_int ]
-        self.tplib.tr_GetNumResults.argtypes = [c_int]
+        self.tr = c_void_p(tr)
+        self.tplib.tr_GetStatus.argtypes = [ c_void_p ]
+        self.tplib.tr_SetStatus.argtypes = [ c_void_p, c_int ]
+        self.tplib.tr_GetSimilarity.argtypes = [ c_void_p ]
+        self.tplib.tr_HasChanged.argtypes = [ c_void_p ]
+        self.tplib.tr_Lock.argtypes = [ c_void_p ]
+        self.tplib.tr_Unlock.argtypes = [ c_void_p ]
 
     def getTrackObject(self):
         return self.tr
@@ -122,11 +120,11 @@ class track(object):
         self.tplib.tr_GetFileName(self.tr, fileName, len)
         return unicode(fileName.value, "UTF-8", 'replace')
 
-    def getTRM(self):
-        trm = c_buffer(TP_ID_LEN)
+    def getPUID(self):
+        puid = c_buffer(TP_ID_LEN)
         len = c_int(TP_ID_LEN)
-        self.tplib.tr_GetTRM(self.tr, trm, len)
-        return unicode(trm.value, "UTF-8", 'replace')
+        self.tplib.tr_GetPUID(self.tr, puid, len)
+        return unicode(puid.value, "UTF-8", 'replace')
 
     def getLocalMetadata(self):
         internal = metadata.metadataInternal()
@@ -167,13 +165,6 @@ class track(object):
     def setChanged(self):
         self.tplib.tr_SetChanged(self.tr)
 
-    # FIXME
-    #def getResults(self):
-    #    return self.tplib.tr_GetResults(self.tr)
-
-    def getNumResults(self):
-        self.tplib.tr_GetNumResults(self.tr)
-
     def lock(self):
         self.tplib.tr_Lock(self.tr)
 
